@@ -34,7 +34,7 @@ require Opcode;
 
 #  Version information
 #
-$VERSION='2.022';
+$VERSION='2.023';
 
 
 #  Get mod_perl version. Clear $@ after evals
@@ -373,7 +373,7 @@ my %constant_temp;
     
     #  Enable Alpine/Vue hack
     #
-    WEBDYNE_ALPINE_VUE_ATTRIBUTE_HACK_ENABLE => 'x:on',
+    WEBDYNE_ALPINE_VUE_ATTRIBUTE_HACK_ENABLE => 'x-on',
 
 
     #  Headers
