@@ -6,6 +6,9 @@ use strict qw(vars);
 use warnings;
 use vars   qw($VERSION);
 
+BEGIN {
+    $ENV{'WEBDYNE_CONF'}='.' unless ($ENV{'WEBDYNE_TEST_FILE_PREFIX'} eq '03');
+}
 
 #  External Modules
 #
@@ -43,17 +46,13 @@ use WebDyne::Util;
 $ENV{'WEBDYNE_TEST_FILE_PREFIX'} ||= '02';
 
 
-#  Override any system webdyne.conf.pl config
-#
-$ENV{'WEBDYNE_CONF'} ||= '.';
-
-
 #  Run
 #
 exit(${&main(\@ARGV) || die err()} || 0);    # || 0 stops warnings
 
 #==================================================================================================
 
+
 sub main {
 
 
